===========================================
External Resources, Videos and Talks
===========================================

For written tutorials, see the :ref:`Tutorial section <tutorial_menu>` of
the documentation.

New to Scientific Python?
==========================
For those that are still new to the scientific Python ecosystem, we highly
recommend the `Python Scientific Lecture Notes
<https://scipy-lectures.org>`_. This will help you find your footing a
bit and will definitely improve your scikit-learn experience.  A basic
understanding of NumPy arrays is recommended to make the most of scikit-learn.

External Tutorials
===================

There are several online tutorials available which are geared toward
specific subject areas:

- `Machine Learning for NeuroImaging in Python <https://nilearn.github.io/>`_
- `Machine Learning for Astronomical Data Analysis <https://github.com/astroML/sklearn_tutorial>`_

.. _videos:

Videos
======

- An introduction to scikit-learn `Part
  I <https://conference.scipy.org/scipy2013/tutorial_detail.php?id=107>`_ and
  `Part II <https://conference.scipy.org/scipy2013/tutorial_detail.php?id=111>`_ at Scipy 2013
  by `Gael Varoquaux`_, `Jake Vanderplas`_  and `Olivier Grisel`_. Notebooks on
  `github <https://github.com/jakevdp/sklearn_scipy2013>`_.

- `Introduction to scikit-learn
  <http://videolectures.net/icml2010_varaquaux_scik/>`_ by `Gael Varoquaux`_ at
  ICML 2010

    A three minute video from a very early stage of scikit-learn, explaining the
    basic idea and approach we are following.

- `Introduction to statistical learning with scikit-learn <https://archive.org/search.php?query=scikit-learn>`_
  by `Gael Varoquaux`_ at SciPy 2011

    An extensive tutorial, consisting of four sessions of one hour.
    The tutorial covers the basics of machine learning,
    many algorithms and how to apply them using scikit-learn. The
    material corresponding is now in the scikit-learn documentation
    section :ref:`stat_learn_tut_index`.

- `Statistical Learning for Text Classification with scikit-learn and NLTK
  <https://pyvideo.org/video/417/pycon-2011--statistical-machine-learning-for-text>`_
  (and `slides <https://www.slideshare.net/ogrisel/statistical-machine-learning-for-text-classification-with-scikitlearn-and-nltk>`_)
  by `Olivier Grisel`_ at PyCon 2011

    Thirty minute introduction to text classification. Explains how to
    use NLTK and scikit-learn to solve real-world text classification
    tasks and compares against cloud-based solutions.

- `Introduction to Interactive Predictive Analytics in Python with scikit-learn <https://www.youtube.com/watch?v=Zd5dfooZWG4>`_
  by `Olivier Grisel`_ at PyCon 2012

    3-hours long introduction to prediction tasks using scikit-learn.

- `scikit-learn - Machine Learning in Python <https://www.youtube.com/watch?v=cHZONQ2-x7I>`_
  by `Jake Vanderplas`_ at the 2012 PyData workshop at Google

    Interactive demonstration of some scikit-learn features. 75 minutes.

- `scikit-learn tutorial <https://www.youtube.com/watch?v=cHZONQ2-x7I>`_ by `Jake Vanderplas`_ at PyData NYC 2012

    Presentation using the online tutorial, 45 minutes.


.. _Gael Varoquaux: https://gael-varoquaux.info
.. _Jake Vanderplas: http://www.vanderplas.com
.. _Olivier Grisel: https://twitter.com/ogrisel
